{% extends "webtemplate_dpaw/base.html" %}

{% block page_content %}
<div class="container-fluid">
    <div class="row">
        <div class="col-xs-12">
            <h4>You are now logged out.</h4>
            <p><a href="{% url 'login' %}">Log in again</a></p>
        </div>
    </div>
</div>
{% endblock %}
