{% extends "webtemplate_dpaw/base.html" %}

{% block page_content %}
<div class="container-fluid">
    <div class="row">
    <div class="col-xs-12">
        <h4>Please log in with your DPaW username and password:</h4>
        <form class="form-horizontal" action="" method="POST">
            {% csrf_token %}
            {% if form.errors %}
                <div class="alert alert-danger">Sorry, that's not a valid username or password.</div>
            {% endif %}
            <div class="form-group">
                <label for="username" class="col-xs-12 col-sm-2 col-md-1 control-label">Username:</label>
                <div class="col-xs-12 col-sm-6 col-md-3">
                    <input type="text" class="form-control" name="username" value="" id="username">
                </div>
            </div>
            <div class="form-group">
                <label for="password" class="col-xs-12 col-sm-2 col-md-1  control-label">Password:</label>
                <div class="col-xs-12 col-sm-6 col-md-3">
                    <input type="password" class="form-control" name="password" value="" id="password">
                </div>
            </div>
            <div class="form-group">
                <div class="col-xs-12 col-sm-offset-2 col-md-offset-1">
                    <button type="submit" class="btn btn-default">Log in</button>
                </div>
            </div>
            <input type="hidden" name="next" value="{{ next }}" />
        </form>
    </div>
</div>
{% endblock %}
